.. bitgauss documentation master file, created by
   sphinx-quickstart on Thu Jun 26 12:48:55 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

bitgauss documentation
======================

This package consists of Python bindings for the `bitgauss` library, which is a Rust library for fast linear algebraic operations over the 2-element field using bit matrices.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. module:: bitgauss

.. autoclass:: bitgauss.BitMatrix
   :members: